@@ -73,10 +73,10 @@ class Command(BaseImporterCommand):
 
             # Only look for tags if it is't going to throw and AttributeError
             if hasattr(entry, 'tags'):
-                tags = [tag.term for tag in entry.tags if tag.scheme != "category"]
+                tags = [t.term for t in entry.tags if t.scheme != "category"]
 
-                # tags have a tendency to not be unique in WP for some reason so
-                # set the list so we have unique
+                # Tags have a tendency to not be unique in WP for
+                # some reason so set the list so we have unique.
                 tags = list(set(tags))
             else:
                 tags = []
