@@ -4,18 +4,17 @@ from django.http import HttpResponseRedirect
 from django.utils.translation import ugettext_lazy as _
 from django.utils.encoding import force_unicode
 
-from mezzanine.conf import settings
 from mezzanine.conf.models import Setting
 from mezzanine.conf.forms import SettingsForm
-from mezzanine.utils import admin_url
+from mezzanine.utils.urls import admin_url
 
 
 class SettingsAdmin(admin.ModelAdmin):
     """
-    Admin class for settings model. Redirect add/change views to the list 
+    Admin class for settings model. Redirect add/change views to the list
     view where a single form is rendered for editing all settings.
     """
-    
+
     def changelist_redirect(self):
         changelist_url = admin_url(Setting, "changelist")
         return HttpResponseRedirect(changelist_url)
@@ -25,7 +24,7 @@ class SettingsAdmin(admin.ModelAdmin):
 
     def change_view(self, *args, **kwargs):
         return self.changelist_redirect()
-    
+
     def changelist_view(self, request, extra_context=None):
         if extra_context is None:
             extra_context = {}
@@ -34,9 +33,10 @@ class SettingsAdmin(admin.ModelAdmin):
             settings_form.save()
             return self.changelist_redirect()
         extra_context["settings_form"] = settings_form
-        extra_context["title"] = _("Change %s" % 
+        extra_context["title"] = _("Change %s" %
             force_unicode(Setting._meta.verbose_name_plural))
-        return super(SettingsAdmin, self).changelist_view(request, extra_context)
+        return super(SettingsAdmin, self).changelist_view(request,
+                                                            extra_context)
 
 
 admin.site.register(Setting, SettingsAdmin)
